
# Type: unit




URI: [biolink:Unit](https://w3id.org/biolink/vocab/Unit)

|  |  |  |
| --- | --- | --- |
| Parent type | | [String](types/String.md) |
| Root (builtin) type | | **str** |

## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | qud:Unit |

